youtube_player_iframe library
Classes
- FullScreenOption
- The fullscreen option.
- PlaybackRate
- Playback rate or speed for the video.
- YoutubeMetaData
- Metadata for the currently loaded video. Fields are empty or zero until a video loads.
- YoutubePlayer
- A widget to play or stream Youtube Videos.
- YoutubePlayerController
- Controls the youtube player, and provides updates when the state is changing.
- YoutubePlayerControllerProvider
- An inherited widget to provide YoutubePlayerController to it's descendants.
- YoutubePlayerIFrameAPI
- Interface for the YouTube IFrame Player API, implemented by YoutubePlayerController.
- YoutubePlayerParams
- Defines player parameters for YoutubePlayer.
- YoutubePlayerScaffold
- A widget that scaffolds the YoutubePlayer and handles fullscreen functionality.
- YoutubePlayerThumbnail
- A widget that shows a YouTube video thumbnail and loads the player in-place when tapped.
- YoutubePlayerValue
- A snapshot of the player's current state, updated by YoutubePlayerController.
- YoutubeValueBuilder
- Widget that builds itself based on the latest snapshot of interaction with a YoutubePlayerController.
- YoutubeVideoState
- The current state of the Youtube video.
Enums
- ListType
- The type of playlist.
- PlayerState
- Current state of the player.
- PointerEvents
- The pointer events.
- ThumbnailFormat
- Format of YouTube video thumbnail.
- ThumbnailQuality
- Quality of YouTube video thumbnail.
- YoutubeError
- Error codes reported by the YouTube IFrame API.
Extensions
- YoutubePlayerControllerExtension on BuildContext
- YoutubePlayerControllerExtension
Typedefs
- YoutubeWebResourceError = WebResourceError
- The Web Resource Error.